@@ -30,6 +30,7 @@ class MockHttpClient(HttpClient):
         self._results[('https://*/api/app/discovery', '')] = self._read_data('discovery_app')
         self._results[('https://mocked-proxy-url/api/token', '')] = self._read_data('discovery_login')
         self._results[('https://mocked-proxy-url/api/proxy/login', '')] = self._read_data('discovery_login')
+        self._results[('https://mocked-proxy-url/api/proxy/account_123', '')] = self._read_data('account')
         self._results[('https://mocked-proxy-url/api/proxy/lift', '')] = self._read_data('discovery_login')
         self._results[('https://mocked-proxy-url/api/proxy/events_123', '')] = self._read_data('proxy_events')
         self._results[(GHOSTFLAME_URL, str(prepare_request_body('create_money_request')))] = self._read_data('money')
@@ -43,6 +44,10 @@ class MockHttpClient(HttpClient):
             'pix_money_request')
         self._results[GHOSTFLAME_URL, str(prepare_request_body('pix_receipt_screen'))] = self._read_data(
             'pix_receipt_screen')
+        self._results[GHOSTFLAME_URL, str(prepare_request_body('account_feed_paginated'))] = self._read_data(
+            'account_feed_paginated')
+        self._results[(GHOSTFLAME_URL, str(prepare_request_body('account_savings')))] = self._read_data(
+            'account_savings')
 
     def add_mock_url(self, url: str, graphql_object: str, response_json_name: str):
         self._results[(url, graphql_object)] = self._read_data(response_json_name)
